package br.usp.cofree;

import java.util.ArrayList;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Check;
import org.apache.wicket.markup.html.form.CheckGroup;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.ImageMap;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.ListView;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.model.CompoundPropertyModel;
import org.apache.wicket.model.Model;
import org.apache.wicket.model.PropertyModel;

import br.usp.cofree.entidade.EstagioCicloVida;
import br.usp.cofree.entidade.FinalidadeProjeto;
import br.usp.cofree.entidade.Licenca;
import br.usp.cofree.entidade.PublicoProjeto;
import br.usp.cofree.entidade.Questionario;
import br.usp.cofree.servicos.ServicosDeQuestionario;


/**
 * Pagina inicial do sistema CoFree. 
 */
public class PaginaInicial extends WebPage {
	
	private Questionario questionario = new Questionario();
	private ServicosDeQuestionario servicosDeQuestionario = new ServicosDeQuestionario();
	
	public PaginaInicial() {
	
        adicionaMenu();

		FeedbackPanel feedbackPanel = new FeedbackPanel("feedback"); //adiciona o componente que escreve msgs de feedback
		add(feedbackPanel);
		
		Form form = new Form("form", new CompoundPropertyModel(questionario)) {
			@Override
			protected void onSubmit() {
				PaginaInicial.this.onFormSubmit();
			}
		}; 
		
		add(form);

		preencheNomeDoProjeto(form);

		preencheIdadeAno(form);	
				
		preencheIdadeMes(form);
		
        preencheLicencas(form);

		preenchePublicoAlvo(form);
   
		preencheFinalidades(form);

		preencheEstagioCicloDeVida(form);
       
		preencheEmail(form);
	}

	private void preencheEmail(Form form) {
		TextField email = new TextField("email");
		email.setLabel(new Model("E-mail do responsável"));
		form.add(email);
	}

	private void preencheNomeDoProjeto(Form form) {
		TextField nomeDoProjeto = new TextField("nomeDoProjeto");
		nomeDoProjeto.setLabel(new Model("Nome do Projeto"));
		form.add(nomeDoProjeto);
	}

	private void preencheIdadeAno(Form form) {
		TextField idadeAno = new TextField("idadeAno", Integer.class);
		idadeAno.setLabel(new Model("Ano do projeto"));
		form.add(idadeAno);
	}

	private void preencheIdadeMes(Form form) {
		TextField idadeMes = new TextField("idadeMes", Integer.class);
		idadeMes.setLabel(new Model("Mês do projeto"));
		form.add(idadeMes);
	}

	private void preencheEstagioCicloDeVida(Form form) {
		final CheckGroup group4 = new CheckGroup("group4", new ArrayList());
        form.add(group4);
        ListView estagios = listarEstagioCicloDeVida();
        group4.add(estagios);
	}

	private void preencheFinalidades(Form form) {
		final CheckGroup group3 = new CheckGroup("group3", new ArrayList());
        form.add(group3);
        ListView finalidades = listarFinalidades();
        group3.add(finalidades);
	}

	private void preenchePublicoAlvo(Form form) {
		final CheckGroup group2 = new CheckGroup("group2", new ArrayList());
        form.add(group2);
        ListView alvos = listarPublicoAlvo();
        group2.add(alvos);
	}

	private void preencheLicencas(Form form) {
		final CheckGroup group = new CheckGroup("group", new ArrayList());
		
		ListView licencasSemRestricao = listarLicencasSemRestricao();
        ListView licencasComRestricaoUso = listarLicencaComRestricaoUso();
        ListView licencasComRestricaoUsoModificacao = listarLicencaComRestricaoUsoModificacao();
        
        group.add(licencasSemRestricao);        
        group.add(licencasComRestricaoUso);
        group.add(licencasComRestricaoUsoModificacao);
        
        form.add(group);
	}

	private void adicionaMenu() {
		add(new ImageMap("imgLogo").addRectangleLink(0, 102, 450, 0, 
        		new BookmarkablePageLink("Aba", PaginaInicial.class)).
        		addRectangleLink(465, 95, 535, 65,new BookmarkablePageLink("Home", Home.class)). //Página Inicial
        		addRectangleLink(550, 95, 620, 65,new BookmarkablePageLink("PaginaInicial2", PaginaInicial.class)). //Cofree
        		addRectangleLink(635, 95, 705, 65,new BookmarkablePageLink("SobreNos", SobreNos.class)). //Sobre Nós
		        addRectangleLink(720, 95, 790, 65,new BookmarkablePageLink("About", About.class))); //About
	}

	/**
	 * @return
	 */
	private ListView listarEstagioCicloDeVida() {
		ListView estagios = new ListView("estagios", new EstagioCicloVida().getEstagiosCicloVida())
        {
           protected void populateItem(ListItem item)
           {
               item.add(new Check("checkbox", item.getModel()));
               item.add(new Label("estagio", new PropertyModel(item.getModel(), "descricao")));
           }
       };
		return estagios;
	}

	/**
	 * @return
	 */
	private ListView listarFinalidades() {
		ListView finalidades = new ListView("finalidades", new FinalidadeProjeto().getFinalidadesProjeto())
        {
           protected void populateItem(ListItem item)
           {
               item.add(new Check("checkbox", item.getModel()));
               item.add(new Label("finalidade", new PropertyModel(item.getModel(), "descricao")));
           }
       };
		return finalidades;
	}

	/**
	 * @return
	 */
	private ListView listarPublicoAlvo() {
		ListView alvos = new ListView("alvos", new PublicoProjeto().getPublicosProjeto())
        {
           protected void populateItem(ListItem item)
           {
               item.add(new Check("checkbox", item.getModel()));
               item.add(new Label("alvo", new PropertyModel(item.getModel(), "descricao")));
           }
       };
		return alvos;
	}

	/**
	 * @return
	 */
	private ListView listarLicencaComRestricaoUsoModificacao() {
		ListView licencas3 = new ListView("licencas3", new Licenca().getLicencasSemRestricao())
        {
            protected void populateItem(ListItem item)
            {
                item.add(new Check("checkbox3", item.getModel()));
                item.add(new Label("licenca3", new PropertyModel(item.getModel(), "nome")));
            }
        };
		return licencas3;
	}

	/**
	 * @return
	 */
	private ListView listarLicencaComRestricaoUso() {
		ListView licencas2 = new ListView("licencas2", new Licenca().getLicencasComRestricaoUso())
        {
            protected void populateItem(ListItem item)
            {
                item.add(new Check("checkbox2", item.getModel()));
                item.add(new Label("licenca2", new PropertyModel(item.getModel(), "nome")));
            }
        };
		return licencas2;
	}

	/**
	 * @return
	 */
	private ListView listarLicencasSemRestricao() {
		ListView licencas = new ListView("licencas", new Licenca().getLicencasSemRestricao())
        {
            protected void populateItem(ListItem item)
            {
                item.add(new Check("checkbox", item.getModel()));
                item.add(new Label("licenca", new PropertyModel(item.getModel(), "nome")));
            }
        };
		return licencas;
	}

	protected void onFormSubmit() {
		//PaginaParecer paginaParecer = new PaginaParecer();
		setResponsePage(PaginaParecer.class);
	}
	
	
}
